@@ -24,16 +24,9 @@ class StringUtils(object):
     @staticmethod
     def md5(data):
         h = hashlib.md5()
-        h.update(data)
+        h.update(data.encode(encoding='utf-8'))
         return h.hexdigest()
 
-    @staticmethod
-    def phoneToNick(phone):
-        if len(phone) > 4:
-            return "zzyl_" + phone[-4:]
-        else:
-            return phone
-
     @staticmethod
     # 将字典转成字符串
     def dict2str(d):
